@@ -30,6 +30,7 @@ from workflowwebtools import clusterworkflows
 from workflowwebtools import classifyerrors
 from workflowwebtools import actionshistorylink
 from workflowwebtools.web.templates import render
+from workflowwebtools.predict import evaluate
 
 from workflowwebtools import statuses
 
@@ -173,6 +174,11 @@ class WorkflowTools(object):
         return sorted(self.prepids.keys())
 
 
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def predict(self, workflow):
+        return evaluate.predict(self.get(workflow))
+
     def get_status(self, workflow):
         status = self.statuses.get(workflow)
         if status is None:
@@ -222,6 +228,15 @@ class WorkflowTools(object):
             key=lambda wkfl: workflow_objs[wkfl['workflow']]['time']
         )
 
+
+    @cherrypy.expose
+    @cherrypy.tools.json_in()
+    def submit2(self):
+        input_json = cherrypy.request.json
+        manageactions.submit2(input_json['documents'])
+        return 'Done'
+
+
     @cherrypy.expose
     def globalerror(self, pievar='errorcode'):
         """
